@@ -31,6 +31,7 @@
 
 #include <orc/orcmips.h>
 #include <orc/orcdebug.h>
+#include <orc/orcinternal.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -294,31 +295,7 @@ orc_mips_load_constants_inner (OrcCompiler *compiler)
       orc_mips_emit_move (compiler, var->ptr_offset, ORC_MIPS_ZERO);
   }
 
-
-  for(i=0;i<compiler->n_insns;i++){
-    OrcInstruction *insn = compiler->insns + i;
-    OrcStaticOpcode *opcode = insn->opcode;
-    OrcRule *rule;
-
-    if (!(insn->flags & ORC_INSN_FLAG_INVARIANT)) continue;
-
-    ORC_ASM_CODE(compiler,"# %d: %s\n", i, insn->opcode->name);
-
-    compiler->insn_shift = compiler->loop_shift;
-    if (insn->flags & ORC_INSTRUCTION_FLAG_X2) {
-      compiler->insn_shift += 1;
-    }
-    if (insn->flags & ORC_INSTRUCTION_FLAG_X4) {
-      compiler->insn_shift += 2;
-    }
-
-    rule = insn->rule;
-    if (rule && rule->emit) {
-      rule->emit (compiler, rule->emit_user, insn);
-    } else {
-      ORC_COMPILER_ERROR(compiler,"No rule for: %s", opcode->name);
-    }
-  }
+  orc_compiler_emit_invariants (compiler);
 }
 
 #define CACHE_LINE_SIZE 32
